@@ -1,4 +1,4 @@
-archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rsml.connect=FALSE, rsml.date=NULL, unitangle="d", rotation=0, numdate=NULL, finalscale=NULL, coldate=par("col"), main=NULL, xlab=NULL, ylab=NULL, zlab=NULL, xlim=NULL, ylim=NULL, zlim=NULL,...){
+archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rsml.connect=FALSE, rsml.date=NULL, unitangle="d", rotation=0, numdate=NULL, finalscale=NULL, coldate=par("col"), twod=NULL, main=NULL, xlab=NULL, ylab=NULL, zlab=NULL, xlim=NULL, ylim=NULL, zlim=NULL,...){
     
     # Errors interception
     
@@ -38,7 +38,13 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
       if (is.character(rsml.date)==TRUE|is.numeric(rsml.date)==TRUE){} else {stop("If rsml.date is not NULL, rsml.date must be a character string or a positive numeric value")}
       if (is.numeric(rsml.date)==TRUE){if (rsml.date<=0|length(rsml.date)>1){stop("If mode(rsml.date) is numeric, rsml.date must be a single positive value")}}}
   
-    # Reading of DART and rsml files
+    if (is.null(twod)==FALSE){
+      if (mode(twod)!="character"){stop("mode(twod) must be character")}
+      if (length(twod)!=2){stop("twod must be a vector of 2 character elements")}
+      twod<-sort(twod)
+      if (all.equal(twod, c("x", "y"))==TRUE|all.equal(twod, c("x", "z"))==TRUE|all.equal(twod, c("y", "z"))==TRUE) {} else {stop("twod must be c(x,y), c(x,z), or c(y,z)")}}
+  
+  # Reading of DART and rsml files
     
     if (is.null(inputlie)==FALSE){
       filenames.lie<-list.files(path=inputlie, pattern="\\.lie$")
@@ -62,7 +68,12 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
     
     if (is.null(inputrsml)==TRUE){ # Only DART files
 
-    LIE<-lapply(paste(path.lie, "/", filenames.lie, sep=""), read.table, header=TRUE)}
+    LIE<-lapply(paste(path.lie, "/", filenames.lie, sep=""), read.table, header=TRUE)
+    
+    #Unit conversion DART files
+    if (unitlength=="mm") {cunit<-(10*cm(1)/res)}
+    if (unitlength=="cm") {cunit<-(cm(1)/res)}
+    if (unitlength=="px") {cunit<-1}}
     
     else {
       
@@ -70,32 +81,102 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
         
         LIE<-list()
         res1<-c()
+        unitlength1<-c()
         filenameslie<-c()
         RSML <- lapply(paste(path.rsml, "/", filenames.rsml, sep=""), rsmlToDART, final.date=rsml.date, connect=rsml.connect)
         for (i in 1:length(RSML)){
           res1<-append(res1, rep(as.numeric(RSML[[i]]$resolution), length(RSML[[i]]$lie)))
+          unitlength1<-append(unitlength1, rep(as.character(RSML[[i]]$length), length(RSML[[i]]$lie)))
           LIE<-append(LIE, RSML[[i]]$lie)
           length1<-length(RSML[[i]]$lie)
           if (length1>1){
             num<-c(1:length1)
             filenameslie[(length(filenameslie)+1):(length(filenameslie)+length1)]<-paste(rep(filenamesrsml[i], length.out=length1), num, sep="")}
           if (length1==1){
-            filenameslie[(length(filenameslie)+1)]<-filenamesrsml[i]}}}
+            filenameslie[(length(filenameslie)+1)]<-filenamesrsml[i]}}
+        
+        #Unit conversion rsml
+        
+        cunit1<-vector(length=length(res1))
+        
+        for (i in 1:length(res1)){
+          
+          if (unitlength=="cm"){
+            
+            if (unitlength1[i]=="pixel") {
+              cunit1[i]<-1
+              message(paste("Unit in ", filenameslie[i], " is pixel. Unitlength not used and results expressed in pixels", sep=""))}
+            if (unitlength1[i]=="m") {cunit1[i]<-100/res1[i]}
+            if (unitlength1[i]=="cm") {cunit1[i]<-1/res1[i]}
+            if (unitlength1[i]=="mm") {cunit1[i]<-1/res1[i]/10}
+            if (unitlength1[i]=="um") {cunit1[i]<-1/res1[i]/10000}
+            if (unitlength1[i]=="nm") {cunit1[i]<-1/res1[i]/10000000}
+            if (unitlength1[i]=="inch") {cunit1[i]<-1/res1[i]*cm(1)}}
+          
+          if (unitlength=="mm"){
+            if (unitlength1[i]=="pixel") {
+              cunit1[i]<-1
+              message(paste("Unit in ", filenameslie[i], " is pixel. Unitlength not used and results expressed in pixels", sep=""))}
+            if (unitlength1[i]=="m") {cunit1[i]<-1/res1[i]*1000}
+            if (unitlength1[i]=="cm") {cunit1[i]<-1/res1[i]*10}
+            if (unitlength1[i]=="mm") {cunit1[i]<-1/res1[i]}
+            if (unitlength1[i]=="um") {cunit1[i]<-1/res1[i]/1000}
+            if (unitlength1[i]=="nm") {cunit1[i]<-1/res1[i]/1000000}
+            if (unitlength1[i]=="inch") {cunit1[i]<-1/res1[i]*cm(1)*10}}
+          
+          if (unitlength=="px"){cunit1[i]<-1}}}
       
       else { # DART and rsml files
         
         res1<-rep(res, length(filenames.lie))
+        unitlength1<-rep(unitlength, length(filenames.lie))
+        
         LIE<-lapply(paste(path.lie, "/", filenames.lie, sep=""), read.table, header=TRUE)
         RSML <- lapply(paste(path.rsml, "/", filenames.rsml, sep=""), rsmlToDART, final.date=rsml.date, connect=rsml.connect)
         for (i in 1:length(RSML)){
           res1<-append(res1, rep(as.numeric(RSML[[i]]$resolution), length(RSML[[i]]$lie)))
+          unitlength1<-append(unitlength1, rep(as.character(RSML[[i]]$length), length(RSML[[i]]$lie)))
           LIE<-append(LIE, RSML[[i]]$lie)
           length1<-length(RSML[[i]]$lie)
           if (length1>1){
             num<-c(1:length1)
             filenameslie[(length(filenameslie)+1):(length(filenameslie)+length1)]<-paste(rep(filenamesrsml[i], length.out=length1), num, sep="")}
           if (length1==1){
-            filenameslie[(length(filenameslie)+1)]<-filenamesrsml[i]}}}}
+            filenameslie[(length(filenameslie)+1)]<-filenamesrsml[i]}}
+        
+        #Unit conversion DART and RSML
+        cunit1<-vector(length=length(res1))
+        
+        if (unitlength=="mm") {cunit1[1:length(filenames.lie)]<-(10*cm(1)/res)}
+        if (unitlength=="cm") {cunit1[1:length(filenames.lie)]<-cm(1)/res}
+        if (unitlength=="px") {cunit1[1:length(filenames.lie)]<-1}
+        
+        for (i in (length(filenames.lie)+1):length(res1)){
+          
+          if (unitlength=="cm"){
+            
+            if (unitlength1[i]=="pixel") {
+              cunit[i]<-1
+              message(paste("Unit in ", filenameslie[i], " is pixel. Unitlength not used and results expressed in pixels", sep=""))}
+            if (unitlength1[i]=="m") {cunit1[i]<-100/res1[i]}
+            if (unitlength1[i]=="cm") {cunit1[i]<-1/res1[i]}
+            if (unitlength1[i]=="mm") {cunit1[i]<-1/res1[i]/10}
+            if (unitlength1[i]=="um") {cunit1[i]<-1/res1[i]/10000}
+            if (unitlength1[i]=="nm") {cunit1[i]<-1/res1[i]/10000000}
+            if (unitlength1[i]=="inch") {cunit1[i]<-1/res1[i]*cm(1)}}
+          
+          if (unitlength=="mm"){
+            if (unitlength1[i]=="pixel") {
+              cunit[i]<-1
+              message(paste("Unit in ", filenameslie[i], " is pixel. Unitlength not used and results expressed in pixels", sep=""))}
+            if (unitlength1[i]=="m") {cunit1[i]<-1/res1[i]*1000}
+            if (unitlength1[i]=="cm") {cunit1[i]<-1/res1[i]*10}
+            if (unitlength1[i]=="mm") {cunit1[i]<-1/res1[i]}
+            if (unitlength1[i]=="um") {cunit1[i]<-1/res1[i]/1000}
+            if (unitlength1[i]=="nm") {cunit1[i]<-1/res1[i]/1000000}
+            if (unitlength1[i]=="inch") {cunit1[i]<-1/res1[i]*cm(1)*10}}
+          
+          if (unitlength=="px"){cunit1[i]<-1}}}}
     
     # Unit conversion and rotation for 2D root systems
     
@@ -110,11 +191,7 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
     
     for (i in 1:length(LIE)){
       
-      if (is.null(inputrsml)==FALSE){res<-res1[i]}
-      
-      if (unitlength=="mm") {cunit<-(10*cm(1)/res)}
-      if (unitlength=="cm") {cunit<-(cm(1)/res)}
-      if (unitlength=="px") {cunit<-1}
+      if (is.null(inputrsml)==FALSE){cunit<-cunit1[i]}
       
       if (!("Z" %in% colnames(LIE[[i]]))){
       LIE[[i]]$X<-LIE[[i]]$X*cunit
@@ -155,26 +232,55 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
       if (is.null(xlab)==TRUE){xlab1<-paste("X (", unitlength, ")", sep="")} else {xlab1<-xlab}
       if (is.null(ylab)==TRUE){ylab1<-paste("Y (", unitlength, ")", sep="")} else {ylab1<-ylab}
       if ("Z" %in% colnames(LIE[[i]]) & is.null(zlab)==TRUE){zlab1<-paste("Z (", unitlength, ")", sep="")} else {zlab1<-zlab}
+      
       if ("Z" %in% colnames(LIE[[i]])){
+        
+        if (is.null(twod)==TRUE){
+        
+        LIE[[i]]$col<-LIE[[i]]$Date
+        for (l in 1:length(coldate1)){LIE[[i]]$col<-replace(LIE[[i]]$col, LIE[[i]]$col==l, coldate1[l])}
         root<-sum(LIE[[i]]$Suiv==0)
         end<-which(LIE[[i]]$Suiv==0)
         open3d()
         plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
+        
         for (k in 1:root){
           if (k==1) {
-            dataroot<-as.matrix(LIE[[i]][k:end[k],7:9])
-            col1<-LIE[[i]]$Date[2:end[k]]} 
+            dataroot<-as.matrix(LIE[[i]][k:end[k],c(7:9,14)])} 
           else {
             if (LIE[[i]]$Prec[end[k-1]+1]!=0){
-              dataroot<-as.matrix(LIE[[i]][(end[k-1]+1):end[k],7:9])
-              dataroot<-rbind(LIE[[i]][LIE[[i]]$Num==LIE[[i]]$Prec[end[k-1]+1],7:9], dataroot)
-              col1<-LIE[[i]]$Date[(end[k-1]+1):end[k]]}
+              dataroot<-as.matrix(LIE[[i]][(end[k-1]+1):end[k],c(7:9,14)])
+              dataroot<-rbind(LIE[[i]][LIE[[i]]$Num==LIE[[i]]$Prec[end[k-1]+1],c(7:9,14)], dataroot)}
             else{
-              dataroot<-as.matrix(LIE[[i]][(end[k-1]+1):end[k],7:9])
-              col1<-LIE[[i]]$Date[(end[k-1]+2):end[k]]}}
-          for (l in 1:length(coldate1)){col1<-replace(col1, col1==l, coldate1[l])}
-          col1<-c("black", col1)
-          lines3d(dataroot, col=col1, smooth=FALSE, ...)}}
+              dataroot<-as.matrix(LIE[[i]][(end[k-1]+1):end[k],c(7:9,14)])}}
+  
+          lines3d(dataroot[,1:3], col=dataroot[,4], smooth=FALSE, ...)}}
+        
+        else {
+          
+          if (all.equal(twod, c("x", "y"))==TRUE){
+          
+            plot(LIE[[i]]$X[1], LIE[[i]]$Y[1], type="n", xlim=xlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=xlab1,...)
+            for (k in 1:nrow(LIE[[i]])){
+              a<-LIE[[i]]$Prec[k]
+              b<-LIE[[i]]$Date[k]
+              if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}
+          
+          if (all.equal(twod, c("x", "z"))==TRUE){
+            
+            plot(LIE[[i]]$X[1], LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=zlim1, main=main1, ylab=zlab1, xlab=xlab1,...)
+            for (k in 1:nrow(LIE[[i]])){
+              a<-LIE[[i]]$Prec[k]
+              b<-LIE[[i]]$Date[k]
+              if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Z[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Z[k], col=coldate1[b],...)}}}
+          
+          if (all.equal(twod, c("y", "z"))==TRUE){
+            
+            plot(LIE[[i]]$Z[1], LIE[[i]]$Y[1], type="n", xlim=zlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=zlab1,...)
+            for (k in 1:nrow(LIE[[i]])){
+              a<-LIE[[i]]$Prec[k]
+              b<-LIE[[i]]$Date[k]
+              if (a!=0){segments(x0=LIE[[i]]$Z[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$Z[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}}}
       
       else {
             plot(LIE[[i]]$X[1], LIE[[i]]$Y[1], type="n", xlim=xlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=xlab1,...)
@@ -184,6 +290,7 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
               if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}}
     
     if (is.null(numdate)==FALSE) {
+      
       for (l in 1:length(numdate)){if (numdate[l]>max(LIE[[i]]$Date)){message(paste("Note: numdate contains a numerical value greater than the number of observation dates in ", filenameslie[i], ". The root system at the last observation date will be plotted.", sep=""))}}
       if (length(coldate)>max(numdate)){message("Note: The number of colors in coldate is greater than max(numdate)")}
       if (length(coldate)<max(numdate)){message("Note: The number of colors in coldate is lower than max(numdate)")}
@@ -201,7 +308,6 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
           minz<-min(LIE[[i]]$Z)
           maxz<-max(LIE[[i]]$Z)}
         for (j in 1:length(numdate)){
-          
           if (is.null(main)==TRUE){main1<-paste(filenameslie[i], "-numdate=", numdate[j], sep="")} else {main1<-main}
           if (is.null(xlim)==TRUE){xlim1<-c(minx,maxx)} else {xlim1<-xlim}
           if (is.null(ylim)==TRUE){ylim1<-c(maxy,miny)} else {ylim1<-ylim}
@@ -209,7 +315,13 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
           if (is.null(xlab)==TRUE){xlab1<-paste("X (", unitlength, ")", sep="")} else {xlab1<-xlab}
           if (is.null(ylab)==TRUE){ylab1<-paste("Y (", unitlength, ")", sep="")} else {ylab1<-ylab}
           if ("Z" %in% colnames(LIE[[i]]) & is.null(zlab)==TRUE){zlab1<-paste("Z (", unitlength, ")", sep="")} else {zlab1<-zlab}
+          
           if ("Z" %in% colnames(LIE[[i]])){
+            
+            if (is.null(twod)==TRUE){
+            
+            LIE[[i]]$col<-LIE[[i]]$Date
+            for (l in 1:length(coldate1)){LIE[[i]]$col<-replace(LIE[[i]]$col, LIE[[i]]$col==l, coldate1[l])}
             dataroot1<-LIE[[i]][LIE[[i]]$Date<=numdate[j],]
             root<-sum(dataroot1$Bran=="true")
             if (root>1) {
@@ -221,20 +333,44 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
             plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
             for (k in 1:root){
                 if (k==1) {
-                  dataroot<-as.matrix(dataroot1[k:end[k],7:9])
-                  col1<-dataroot1$Date[2:end[k]]} 
+                  dataroot<-as.matrix(dataroot1[k:end[k],c(7:9,14)])} 
                 else {
                   if (dataroot1$Prec[end[k-1]+1]!=0){
-                    dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],7:9])
-                    dataroot<-rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],7:9], dataroot)
-                    col1<-dataroot1$Date[(end[k-1]+1):end[k]]}
+                    dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9,14)])
+                    dataroot<-rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],c(7:9,14)], dataroot)}
                   else{
-                    dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],7:9])
-                    col1<-dataroot1$Date[(end[k-1]+2):end[k]]}}
+                    dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9,14)])}}
                 
-              for (l in 1:length(coldate1)){col1<-replace(col1, col1==l, coldate1[l])}
-              col1<-c("black", col1)
-              lines3d(dataroot, col=col1, smooth=FALSE, ...)}} 
+              lines3d(dataroot[,1:3], col=dataroot[,4], smooth=FALSE, ...)}}
+            
+            else {
+              
+              if (all.equal(twod, c("x", "y"))==TRUE){
+                
+                plot(LIE[[i]]$X[1], LIE[[i]]$Y[1], type="n", xlim=xlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=xlab1,...)
+                for (k in 1:nrow(LIE[[i]])){
+                  if (LIE[[i]]$Date[k]<=numdate[j]){
+                  a<-LIE[[i]]$Prec[k]
+                  b<-LIE[[i]]$Date[k]
+                  if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}}
+              
+              if (all.equal(twod, c("x", "z"))==TRUE){
+                
+                plot(LIE[[i]]$X[1], LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=zlim1, main=main1, ylab=zlab1, xlab=xlab1,...)
+                for (k in 1:nrow(LIE[[i]])){
+                  if (LIE[[i]]$Date[k]<=numdate[j]){
+                  a<-LIE[[i]]$Prec[k]
+                  b<-LIE[[i]]$Date[k]
+                  if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Z[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Z[k], col=coldate1[b],...)}}}}
+              
+              if (all.equal(twod, c("y", "z"))==TRUE){
+                
+                plot(LIE[[i]]$Z[1], LIE[[i]]$Y[1], type="n", xlim=zlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=zlab1,...)
+                for (k in 1:nrow(LIE[[i]])){
+                  if (LIE[[i]]$Date[k]<=numdate[j]){
+                  a<-LIE[[i]]$Prec[k]
+                  b<-LIE[[i]]$Date[k]
+                  if (a!=0){segments(x0=LIE[[i]]$Z[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$Z[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}}}} 
               
               else {
                 plot(LIE[[i]]$X[1], LIE[[i]]$Y[1], type="n", xlim=xlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=xlab1,...)
@@ -276,6 +412,11 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
           if ("Z" %in% colnames(LIE[[i]]) & is.null(zlab)==TRUE){zlab1<-paste("Z (", unitlength, ")", sep="")} else {zlab1<-zlab}
           
           if ("Z" %in% colnames(LIE[[i]])){
+            
+            if (is.null(twod)==TRUE){
+            
+            LIE[[i]]$col<-LIE[[i]]$Date
+            for (l in 1:length(coldate1)){LIE[[i]]$col<-replace(LIE[[i]]$col, LIE[[i]]$col==l, coldate1[l])}
             dataroot1<-LIE[[i]][LIE[[i]]$Date<=numdate[j],]
             root<-sum(dataroot1$Bran=="true")
             if (root>1) {
@@ -285,22 +426,47 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
             else {end<-nrow(dataroot1)}
             open3d()
             plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
+            
             for (k in 1:root){
               if (k==1) {
-                dataroot<-as.matrix(dataroot1[k:end[k],7:9])
-                col1<-dataroot1$Date[2:end[k]]} 
+                dataroot<-as.matrix(dataroot1[k:end[k],c(7:9,14)])} 
               else {
                 if (dataroot1$Prec[end[k-1]+1]!=0){
-                  dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],7:9])
-                  dataroot<-rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],7:9], dataroot)
-                  col1<-dataroot1$Date[(end[k-1]+1):end[k]]}
+                  dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9,14)])
+                  dataroot<-rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],c(7:9,14)], dataroot)}
                 else{
-                  dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],7:9])
-                  col1<-dataroot1$Date[(end[k-1]+2):end[k]]}}
+                  dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9,14)])}}
               
-              for (l in 1:length(coldate1)){col1<-replace(col1, col1==l, coldate1[l])}
-              col1<-c("black", col1)
-              lines3d(dataroot, col=col1, smooth=FALSE, ...)}} 
+              lines3d(dataroot[,1:3], col=dataroot[,4], smooth=FALSE, ...)}}
+            
+            else {
+              
+              if (all.equal(twod, c("x", "y"))==TRUE){
+                
+                plot(LIE[[i]]$X[1], LIE[[i]]$Y[1], type="n", xlim=xlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=xlab1,...)
+                for (k in 1:nrow(LIE[[i]])){
+                  if (LIE[[i]]$Date[k]<=numdate[j]){
+                    a<-LIE[[i]]$Prec[k]
+                    b<-LIE[[i]]$Date[k]
+                    if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}}
+              
+              if (all.equal(twod, c("x", "z"))==TRUE){
+                
+                plot(LIE[[i]]$X[1], LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=zlim1, main=main1, ylab=zlab1, xlab=xlab1,...)
+                for (k in 1:nrow(LIE[[i]])){
+                  if (LIE[[i]]$Date[k]<=numdate[j]){
+                    a<-LIE[[i]]$Prec[k]
+                    b<-LIE[[i]]$Date[k]
+                    if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Z[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Z[k], col=coldate1[b],...)}}}}
+              
+              if (all.equal(twod, c("y", "z"))==TRUE){
+                
+                plot(LIE[[i]]$Z[1], LIE[[i]]$Y[1], type="n", xlim=zlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=zlab1,...)
+                for (k in 1:nrow(LIE[[i]])){
+                  if (LIE[[i]]$Date[k]<=numdate[j]){
+                    a<-LIE[[i]]$Prec[k]
+                    b<-LIE[[i]]$Date[k]
+                    if (a!=0){segments(x0=LIE[[i]]$Z[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$Z[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}}}} 
           
           else {
                   plot(LIE[[i]]$X[1], LIE[[i]]$Y[1], type="n", xlim=xlim1, ylim=ylim1, main=main1, ylab=ylab1, xlab=xlab1,...)
@@ -308,4 +474,4 @@ archidraw<-function(inputlie=NULL, inputrsml=NULL, res=NULL, unitlength="px", rs
                     if (LIE[[i]]$Date[k]<=numdate[j]){
                       a<-LIE[[i]]$Prec[k]
                       b<-LIE[[i]]$Date[k]
-                      if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Y[k], col=coldate1[b], ,...)}}}}}}}}}
\ No newline at end of file
+                      if (a!=0){segments(x0=LIE[[i]]$X[a],y0=LIE[[i]]$Y[a],x1=LIE[[i]]$X[k],y1=LIE[[i]]$Y[k], col=coldate1[b],...)}}}}}}}}}
\ No newline at end of file
